@@ -29,11 +29,11 @@ class Account(BaseDataClass['AccountResponse']):
     profile_image: str
     #: This is true if the account is a junior account, false if the account is a non-junior account. 
     is_junior: bool
-    #: This is a list of platforms a user plays on. It has these possible values ``['Steam', 'Meta', 'PlayStation', 'Xbox', 'RecNet', 'iOS', 'Android', 'Standalone']``.   
+    #: This is a list of platforms a user plays on. It has these possible values `['Steam', 'Meta', 'PlayStation', 'Xbox', 'RecNet', 'iOS', 'Android', 'Standalone']`.   
     platforms: List[str]
-    #: This is the list of pronouns a user goes by. It has these possible values ``['She / her', 'He / him', 'They / them', 'Ze / hir', 'Ze / zir', 'Xe / xem']``.  
+    #: This is the list of pronouns a user goes by. It has these possible values `['She / her', 'He / him', 'They / them', 'Ze / hir', 'Ze / zir', 'Xe / xem']`.  
     personal_pronouns: List[str]
-    #: This is a list of a user's gender identities. It has these possible values ``['LGBTQIA', 'Transgender', 'Bisexual', 'Lesbian', 'Pansexual', 'Asexual', 'Intersex', 'Genderqueer', 'Nonbinary', 'Aromantic']``.  
+    #: This is a list of a user's gender identities. It has these possible values `['LGBTQIA', 'Transgender', 'Bisexual', 'Lesbian', 'Pansexual', 'Asexual', 'Intersex', 'Genderqueer', 'Nonbinary', 'Aromantic']`.  
     identity_flags: List[str] 
     #: This is the date the account was created as a Unix integer. 
     created_at: int
@@ -73,7 +73,7 @@ class Account(BaseDataClass['AccountResponse']):
         self.display_name = data['displayName']
         self.profile_image = data['profileImage']
         self.banner_image = data.get("bannerImage", None)
-        self.is_junior = bool(data['isJunior'])
+        self.is_junior = data['isJunior']
         self.platforms = bitmask_decode(data['platforms'], PLATFORM_LIST)
         self.personal_pronouns = bitmask_decode(data['personalPronouns'], PERSONAL_PRONOUNS_LIST)
         self.identity_flags = bitmask_decode(data['identityFlags'], IDENTITY_FLAGS_LIST)
